==> openshift-model-miscellaneous-5.12.3-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class APIRequestCountBuilder extends io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluentImpl<io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountBuilder>{
  public APIRequestCountBuilder() {
    this(false);
  }
  public APIRequestCountBuilder(java.lang.Boolean validationEnabled) {
    this(new APIRequestCount(), validationEnabled);
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new APIRequestCount(), validationEnabled);
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount instance) {
    this(instance,false);
  }
  public APIRequestCountBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCount build() {
    APIRequestCount buildable = new APIRequestCount(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIRequestCountBuilder that = (APIRequestCountBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class APIRequestCountBuilder extends APIRequestCountFluentImpl<APIRequestCountBuilder> implements VisitableBuilder<APIRequestCount,APIRequestCountBuilder>{
  public APIRequestCountBuilder() {
    this(false);
  }
  public APIRequestCountBuilder(Boolean validationEnabled) {
    this(new APIRequestCount(), validationEnabled);
  }
  public APIRequestCountBuilder(APIRequestCountFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountBuilder(APIRequestCountFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new APIRequestCount(), validationEnabled);
  }
  public APIRequestCountBuilder(APIRequestCountFluent<?> fluent,APIRequestCount instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountBuilder(APIRequestCountFluent<?> fluent,APIRequestCount instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountBuilder(APIRequestCount instance) {
    this(instance,false);
  }
  public APIRequestCountBuilder(APIRequestCount instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  APIRequestCountFluent<?> fluent;
  Boolean validationEnabled;
  public APIRequestCount build() {
    APIRequestCount buildable = new APIRequestCount(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
